@@ -742,6 +742,7 @@ def sample(
 
     if var_names is not None:
         trace_vars = [v for v in model.unobserved_RVs if v.name in var_names]
+        trace_vars = model.replace_rvs_by_values(trace_vars)
         assert len(trace_vars) == len(var_names), "Not all var_names were found in the model"
     else:
         trace_vars = None
@@ -1041,8 +1042,8 @@ def _sample(
             for it, diverging in enumerate(sampling_gen):
                 if it >= skip_first and diverging:
                     _pbar_data["divergences"] += 1
-                progress.update(task, advance=1)
-            progress.update(task, advance=1, completed=True)
+                progress.update(task, refresh=True, advance=1)
+            progress.update(task, refresh=True, advance=1, completed=True)
         except KeyboardInterrupt:
             pass
 
