@@ -178,7 +178,7 @@ def find_MAP(
             if isinstance(e, StopIteration):
                 pm._log.info(e)
         finally:
-            cost_func.progress.update(cost_func.task, completed=cost_func.n_eval)
+            cost_func.progress.update(cost_func.task, completed=cost_func.n_eval, refresh=True)
             print(file=sys.stdout)
 
     mx0 = RaveledVars(mx0, x0.point_map_info)
@@ -223,6 +223,7 @@ class CostFuncWrapper:
             *Progress.get_default_columns(),
             TextColumn("{task.fields[loss]}"),
             console=Console(theme=progressbar_theme),
+            disable=not progressbar,
         )
         self.task = self.progress.add_task("MAP", total=maxeval, visible=progressbar, loss="")
 
