@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -257,7 +257,7 @@ def test_default_value_transform_logprob(pt_dist, dist_params, sp_dist, size):
         if a_val.ndim > 0:
 
             def jacobian_estimate_novec(value):
-                dim_diff = a_val.ndim - value.ndim  # pylint: disable=cell-var-from-loop
+                dim_diff = a_val.ndim - value.ndim
                 if dim_diff > 0:
                     # Make sure the dimensions match the expected input
                     # dimensions for the compiled backward transform function
@@ -550,7 +550,7 @@ def test_scan_transform():
     innov = []
     prev_innov = init
     for i in range(4):
-        next_innov = pt.random.beta(prev_innov * 10, (1 - prev_innov) * 10, name=f"innov[i]")
+        next_innov = pt.random.beta(prev_innov * 10, (1 - prev_innov) * 10, name="innov[i]")
         innov.append(next_innov)
         prev_innov = next_innov
     innov = pt.stack(innov)
