@@ -16,7 +16,7 @@ import numpy as np
 import numpy.testing as npt
 import pytest
 
-from pymc import ConstantData, Model, Normal, sample
+from pymc import Data, Model, Normal, sample
 
 
 @pytest.mark.parametrize("nuts_sampler", ["pymc", "nutpie", "blackjax", "numpyro"])
@@ -26,8 +26,8 @@ def test_external_nuts_sampler(recwarn, nuts_sampler):
 
     with Model():
         x = Normal("x", 100, 5)
-        y = ConstantData("y", [1, 2, 3, 4])
-        ConstantData("z", [100, 190, 310, 405])
+        y = Data("y", [1, 2, 3, 4])
+        Data("z", [100, 190, 310, 405])
 
         Normal("L", mu=x, sigma=0.1, observed=y)
 
